;--DRAWING ROUTINES--
TileBlock
;hl-position of left upper corner, bc-block size, de-tile address in memory	
	
TileBl1	PUSH BC
		PUSH DE
		PUSH HL

;draws one horizontal line of tiles
TileBl2		PUSH BC
			PUSH DE
			
			PUSH HL
			CALL DrawTile; draw a single tile
			POP HL
			
			POP DE ; restore screen position and tile data address
	
			LD A,(DE)
			LD B,A ;read tile width from memory  to b
	
			LD A,L
			ADD A,B
			LD L,A; count horizontal coordinate of next tile in the line
	 			  ;(add b=tile size to coordinate of previous tile)
			
			POP BC	;restore block size in bc
			DJNZ TileBl2 ;decrease number of tiles in the line yet to do
		
		
; draw c lines of tiles
	POP HL
	POP DE
	
	INC DE
	LD A,(DE)	;read tile height from memory to C
	LD C,A	
	DEC DE	
	
		LD A,L	
TileBl3	ADD A,32 ;go c lines down,because c=tile height
		DEC C
		JR NZ, TileBl3
		LD L,A
		JR NC,TileBl4
		LD A,H
		ADD A,8;next screen segment
		LD H,A		
		
				
TileBl4	POP BC ;restore block size in bc
		DEC C	;decrease number of columns left to do
		JR NZ, TileBl1
		
		RET


;--------------------
DrawTile:
;hl-position,de-address
;first 2 sprite bytes contain size of the sprite
;bc register is loaded with size

	LD A,(DE)
	LD B,A ; x width
	INC DE
	LD A,(DE)
	LD C,A ; y-height	
	INC DE			
	
DrawTile0				
	PUSH HL ;store screen position
	PUSH BC	;store data adress		
								
;this loop draw "c" lines of chars
DrawTile1	PUSH HL
			PUSH BC
		
;this loop draws one line of chars
DrawTile2					
					PUSH HL
					PUSH BC
					LD B,8			
					
;this loop draws one char
	LD A,(DE)
	CP 16
	JR Z,DrawTile3Empty

DrawTile3Normal			
					LD A, (DE)
					LD (HL),A ;repeated 8 times
					INC H
					INC DE
					DJNZ DrawTile3Normal
					JR DrawTile4

DrawTile3Empty
		XOR A ;fills char square with zeroes
			  ;takes less memory than storing all the zeroes
		INC DE ;goes to next byte of data															
DrawTile3Empty2		
		LD (HL),A
		INC H
		DJNZ DrawTile3Empty2
			  
			  
			  
			  				
DrawTile4		POP BC
				LD A,L
				POP HL ;restores h to address of upper row of the line
				LD L,A
				INC L	;moves one char right 
					 
				DJNZ DrawTile2 ;repeat until whole line of chars is drawn
				
				POP BC
				POP HL		
			; goes to another line of chars in the sprite
			LD A,L
			ADD A,32
			LD L,A
			JR NC,DrawTile5;not carry=no going to next segment, so no h changes needed
				
				;change h only if going to next screen segment	
			LD A,H
			ADD A,8
			LD H,A
					
DrawTile5			
			DEC C ;decrease number of chars line left to do
			JR NZ, DrawTile1
;--------
;Attributes
					
; tile drawing is finished
; now restore tile size into BC and position into HL
;  de is already increased to next byte where attributes data begin	
		POP BC
		POP HL		
;So BC-size,DE-data address, hl-screen position						
		
;transform graphic address to attribute address
TileAttr		
		LD A,80
		SRL H
		SRL H
		SRL H
		ADD A,H
		LD H,A
			
;draw c lines of attributes
TileAttr1 	PUSH BC
			PUSH HL
		
;draw one line of attributes
TileAttr2   LD A,(DE)
			LD (HL),A
TileAttr3	INC HL ;goes to next square in the row
			INC DE
			DJNZ TileAttr2
	
		POP HL
		PUSH DE ;goes to next row of attributes	
		LD DE,32   
		ADD HL,DE  
		POP DE 
			 
		POP BC
		DEC C ;decrease number of lines left to do 
		JR NZ, TileAttr1
		RET
		
;------------------------
StartScreen

	CALL ClearScreen
	
	LD HL,22528 ;sky
	LD A,40
	LD (HL),A
	LD DE,22529
	LD BC,415
	LDIR
	
	LD HL,22976 ;houses
	LD A,8
	LD (HL),A
	LD DE,22977
	LD BC,159
	LDIR
	
	LD HL,20576 ;water
	LD DE,Water
	LD BC, 32*256+1
	CALL TileBlock
	
	LD HL,18528;roofs
	LD DE,Roof
	LD BC,8*256+1
	CALL TileBlock
	
	LD HL,18625 ;windows
	LD DE,Windows
	LD B,16
Dss2
	PUSH BC
	PUSH DE
	PUSH HL
	CALL DrawTile
	POP HL
	POP DE
	POP BC
	INC L
	INC L
	DJNZ Dss2

;change color of some houses from blue to red	
	LD HL,22913
	LD B,4
	
Dss3
	PUSH HL
	PUSH BC
	CALL ColorHouse
	POP BC
	POP HL
	
	LD A,L
	ADD A,8
	LD L,A
	DJNZ Dss3
	
;corerect connections of the houses
	LD HL,18624
	LD DE,Connection1 ;blue - red
	
	LD B,4
Dss4	
	PUSH HL
	PUSH DE
	PUSH BC

	LD BC,1*256+5
	CALL TileBlock
	POP BC
	POP DE
	POP HL
	LD A,L
	ADD A,8
	LD L,A
	DJNZ Dss4
	
	LD HL,18628
	LD DE,Connection2; red - blue
	
	LD B,4
Dss5	
	PUSH HL
	PUSH DE
	PUSH BC

	LD BC,1*256+5
	CALL TileBlock
	POP BC
	POP DE
	POP HL
	LD A,L
	ADD A,8
	LD L,A
	DJNZ Dss5
	
;display texts
	LD A,2;print in screen
	CALL 5633	
	
	LD BC,256*(24-5)+(33-6); print at 5,6
	CALL 3545
	
	LD DE,HolidayText
	LD BC,21
	CALL 8252 ;print "holidays in amsterdam"	
	
	LD BC,256*(24-8)+(33-11); print at 8,11
	CALL 3545
	
	LD A,17
	RST 16
	LD A,5
	RST 16 ;blue paper for Basic routine
	LD DE,FireText
	LD BC,10
	CALL 8252 ;print "press fire"	
	
StartScreenWait
	LD BC,31; read joystick
	IN A,(C)
	BIT 4,A ;check fire
	JR Z, StartScreenWait
	
	RET


	
	
;-------
;make some houses red
ColorHouse	
	LD DE,29
	LD C,7
ColorHouse2
	LD B,3
	
ColorHouse3
	LD A,(HL)
	AND 00111000b ; extract paper
	CP 8 ;blue wall?
	JR NZ, ColorHouse4 ;if not, skip code
	
	;blue wall must be changed to red
	LD A,(HL)
	AND 00000111b; take ink
	OR  00010000b; add red paper
	LD (HL),A; change attribute
	
ColorHouse4	
	LD A,(HL)
	AND 00000111b ; extract ink
	CP 7; white ink=wndow
	JR NZ, ColorHouse5 ;if not, skip code
	
	;change window from white to yellow
	LD A,(HL)
	AND 00111000b; take paper
	OR  00000110b; add yellow ink
	LD (HL),A; change attribute

ColorHouse5		
	INC L
	DJNZ ColorHouse3
	
	ADD HL,DE ;go one line down
	DEC C
	JR NZ, ColorHouse2
	RET



;---------------------------------------------------------------
;Draw game screen

DrawScreen
		CALL ClearScreen
		
;draw tile blocks
		LD B,10
		LD HL,BlocksData-1
		
ScreenBlocks:
		PUSH BC ;store number of blocks
				
		INC HL 
		LD B,(HL)
		INC HL
		LD C,(HL);BC is loaded with block size
		
		INC HL
		LD E,(HL)
		INC HL
		LD D,(HL);DE is loaded with tile address		
		
		PUSH HL
		PUSH DE		
		INC HL
		LD D,(HL)
		INC HL
		LD E,(HL)
		LD H,D
		LD L,E ;HL is loaded with position (with some swap help of DE)
		POP DE					
	
		CALL TileBlock		;draw a single block	
		
		POP HL			;restore  blocks data addresses in hl
		INC HL
		INC HL	;go to next block (skip 2 bytes with position which were loaded to HL)
		
		POP BC	;restore and decrease number of blocks left to do					
		DJNZ ScreenBlocks
		
		
;Draw single tiles
		LD B,23
		LD HL,TilesData
		
ScreenTiles:
		PUSH BC ;store number of tiles
		
		LD E,(HL)
		INC HL
		LD D,(HL);DE is loaded with tile address
				
		INC HL 
		LD B,(HL)
		INC HL
		LD C,(HL);BC is loaded with screen position
		
		PUSH HL
		LD H,B
		LD L,C ;position copied to HL	
		CALL DrawTile		;draw a single tile	
		POP HL			;restore  tiles data addresses in hl
		INC HL
		
		
		POP BC	;restore and decrease number of tiles left to do					
		DJNZ ScreenTiles
		
;----------graphics in backbuffer	

;clear backbuffers (ther could be some garbage bytes left)
	XOR A
	LD HL,roadBuffer1
	LD (HL),A
	LD DE, roadBuffer1+1
	LD BC, 2047;graphics
	LDIR
	LD HL,roadBuffer2
	LD (HL),A
	LD DE, roadBuffer2+1
	LD BC, 2047;graphics
	LDIR	
	
;draw four rows of bikes in backbuffer1
	LD HL,roadBuffer1+4
	LD DE,Bike1
	PUSH DE
	CALL DrawBikes
	POP DE
	LD HL,roadBuffer1+128
	CALL DrawBikes
	
	LD HL,roadBuffer1+68
	LD DE,Bike3
	PUSH DE
	CALL DrawBikes
	POP DE
	LD HL,roadBuffer1+193
	CALL DrawBikes
	
;and in backbuffer2
	
	LD HL,roadBuffer2+4
	LD DE,Bike2
	PUSH DE
	CALL DrawBikes
	POP DE
	LD HL,roadBuffer2+128
	CALL DrawBikes
	
	LD HL,roadBuffer2+68
	LD DE,Bike4
	PUSH DE
	CALL DrawBikes
	POP DE
	LD HL,roadBuffer2+193
	CALL DrawBikes
	
	
	RET
;-----
DrawBikes
	LD B,3; nr of bikes
	
DrawBikes2:
	PUSH HL
	PUSH BC
	PUSH DE
	CALL DrawTile
	POP DE
	POP BC
	POP HL
	LD A,L
	ADD	A,12
	LD L,A
	DJNZ DrawBikes2		
	
	RET ;end of screen drawing

;--------------------
ClearScreen
	XOR A
	OUT (254),A ;black border
	LD HL,16384
	LD (HL),A
	LD DE, 16385
	LD BC, 6143;graphics
	LDIR
	
	INC HL
	INC DE
	LD A,71
	LD (HL),A
	LD BC,767;attributes
	LDIR
	RET
;--------------------


DrawMenu
	LD A,1 ;print in bottom
	CALL 5633
		
	LD BC,256*(24-0)+(33-0); print at 0,0
	CALL 3545
	
	LD DE,MenuText ;text address
	LD BC,26 ;length of text
	CALL 8252 ;print
	
;attribute	
	LD HL,22528+736
	LD A,68
	LD B,32
DrawMenu2
	LD (HL),A
	INC HL
	DJNZ DrawMenu2	

;-----------	
DrawCounters
	LD HL,22528+704; address of attribute line with meters
	LD DE,ganjaMeter; start address of meters
	LD B,4; four counters

DrawCounters2
	PUSH BC
	LD A,(DE) ;read meter
	BIT 7,A ;bit 7 means a=255 or so that is less than zero
	JR Z, DrawCounter25; if it is not true just continue
	LD (gameOverStatus),A ;the meter is less than 0 so set GameOver
	XOR A; but still display counter =0
	
	
DrawCounter25	
	LD B,A ;read meter
	LD A,7
	SUB B
	LD C,A; number of empty spaces	
	
	LD A,B
	OR A
	JR Z,DrawCounter35; skip drawing yellow bar if the length of it is 0
	
	LD A,48	
DrawCounters3
	LD (HL),A ;draw meter
	INC HL
	DJNZ DrawCounters3
		
DrawCounter35	
	LD B,C
	LD A,16 ;red colors means meter depleted
DrawCounters4
	LD (HL),A ;draw empty space
	INC HL
	DJNZ DrawCounters4
	
	DEC HL ;separate meters with black space
	XOR A
	LD (HL),A
	INC HL
	
	INC DE
	POP BC
	DJNZ DrawCounters2
	
;typing score now	
DrawScore
	LD BC,256*(24-1)+(33-12); print at 1,12
	CALL 3545
	
	LD DE,MenuText2
	LD BC,6
	CALL 8252 ;print "score:"
	LD BC,(score)
	CALL 6683 ; print score
;attribute	of line with score
	LD HL,22528+736
	LD A,68
	LD B,32
DrawScore2
	LD (HL),A
	INC HL
	DJNZ DrawScore2	
	
	
	RET
;------------------
DecreaseCounters
;routine is called at certain intervals of time
 LD HL,ganjaMeter	
 DEC (HL)
 INC HL ;go to sex meter
 DEC (HL)
 CALL DrawCounters
 JP MoveBikes
 
RestoreCounter
 ;routine is called when player has ganja or sex
 ;hl containt address of counter
 LD A,6
 LD (HL),A ;restore proper counter
 LD HL,moneyMeter
 DEC (HL) ;decrease money
 INC HL ;go to power meter
 DEC (HL);decrease power
 DEC (HL)
 RET
 
;-----end of game-------	
GameOver
	
;some crash sound and border effects

;turn off AY Sound
	LD BC,65533 
	LD A,7
 	OUT (C),A ;register chosen
 
 	LD BC,49149
 	LD A,63
	OUT (C),A
	

GameOverBorder		
	LD A,R
	OUT (254),A
	HALT
	XOR A
	OUT (254),A
	DJNZ GameOverBorder		
	
	
;game over screen
	CALL ClearScreen
	LD A,2;print in screen
	CALL 5633	
	
	LD BC,256*(24-8)+(33-11); print at 11,8
	CALL 3545
	
	LD DE,EndText1
	LD BC,11
	CALL 8252 ;print "Game Over"
	
	LD DE,GanjaCountText
	LD BC,13
	CALL 8252 ;print "GanjaCount"
	LD A,(ganjaCount)
	LD C,A
	LD B,0
	CALL 6683 ; print number of ganjas
	LD DE,SexCountText
	LD BC,13
	CALL 8252 ;print "Sex"
	LD A,(sexCount)
	LD C,A
	LD B,0
	CALL 6683 ; print number of sex
	
;determine cause of death
	LD A,(gameOverStatus)
	CP 13
	JR Z,HitBike

	LD HL,ganjaMeter
	LD A,(HL) ;check ganja
	BIT 7,A
	JR NZ,NoSexGanja
	INC HL
	LD A,(HL) ;check sex
	BIT 7,A			
	JR NZ,NoSexGanja
	INC HL
	LD A,(HL) ;check money
	BIT 7,A			
	JR NZ,NoMoney
	INC HL
	LD A,(HL) ;check power
	BIT 7,A			
	JR NZ,NoPower
	
HitBike
	LD DE,EndText2
	LD BC,25
	JR DeathCauseText	

NoMoney
	LD DE,EndText4
	LD BC,19
	JR DeathCauseText
NoPower
	LD DE,EndText5
	LD BC,19
	JR DeathCauseText
	
NoSexGanja
	LD DE,EndText3
	LD BC,29
DeathCauseText
	CALL 8252 ;print
	
	;red letters
	LD HL,22528
	LD A,66
	LD (HL),A
	LD DE,22529
	LD BC,767
	LDIR	

	
	
GameOverWait
	LD BC,31; read joystick
	IN A,(C)
	BIT 4,A ;check fire
	JR Z, GameOverWait
	
   JP StartGame2; fire pressed = begin new game
	
;---texts---
MenuText BYTE "GANJA  SEX    MONEY  POWER"	
MenuText2 BYTE "SCORE:"
EndText1 BYTE "GAME OVER",13,13 ;13 means enter= go to next line
EndText2 BYTE 13,13,"Beware of deadly bikes!"
EndText3 BYTE 13,13,"Satisfy your urges on time!"
EndText4 BYTE 13,13,"No cash no fun :("
EndText5 BYTE 13,13,"Remember to rest!"
GanjaCountText BYTE "Ganja count: "
SexCountText BYTE 13,13,"Sex count: "
HolidayText BYTE "HOLIDAYS IN AMSTERDAM"
FireText	BYTE "Press Fire"

;----------------
;GRAPHICS
;----------------

Blank
	BYTE 1,1
	BYTE 16,71
RedBlank
	BYTE 1,1
	BYTE 16,80

 
CoffeeShop:
	BYTE 4,3
	BYTE	  0,127,127,103, 95, 94, 93, 93
	BYTE	  0,255,255,255,255,237, 91, 73
	BYTE	  0,255,255,255,255,187, 85, 17
	BYTE	  0,254,254,254,254,254,254,254
	BYTE	 93,102,127,127,102, 90, 94,102
	BYTE	 91,219,219,219,255,255,255,118
	BYTE	119,153,255,255,238,230,226,113
	BYTE	254,254,126,126, 58, 50, 34, 70
	BYTE	122, 90,102,127,127,127,127,  0
	BYTE	170,170,170,246,254,255,255,  0
	BYTE	177,184,102,193,231,255,255,  0
	BYTE	 70, 14, 50, 64,114,126,254,  0
	BYTE	 68, 68, 68, 68, 70, 70, 70, 70
	BYTE	 66, 66, 66, 66
	BYTE	 68, 68, 68, 68, 70, 70, 70, 70
	BYTE	 66, 66, 66, 66
	
SexShop:
	BYTE 3,2
	BYTE	255,128,128,158,191,179,176,190
	BYTE	255,  0,  0,125,125, 96, 96,120
	BYTE	255,  1,  1,141,141,217,217,113
	BYTE	159,131,179,191,158,128,128,255
	BYTE	120, 96, 96,125,125,  0,  0,255
	BYTE	113,217,217,141,141,  1,  1,255
	BYTE	214,214,214,214,214,214
	
Bank:
	BYTE 3,2
	BYTE	255,  0,255,  0,  0, 60, 50, 50
	BYTE	255,  0,255,  0,  0,100,214,214
	BYTE	255,  0,255,  0,  0,164,172,184
	BYTE	 60, 50, 50, 60,  0,255,  0,255
	BYTE	247,213,213,212,  0,255,  0,255
	BYTE	176,184,172,164,  0,255,  0,255
	BYTE	105,105,105,41,41,41
Hotel:
	BYTE 3,2
	BYTE	 85,170,  0,255,255,168,170,138
	BYTE	 85,170,  0,255,255,136,219,217
	BYTE	 80,168,  0,248,248,186,186,186
	BYTE	170,168,255,255,  0, 85, 42,  0
	BYTE	219,216,255,255,  0, 85,170,  0
	BYTE	186,138,248,248,  0, 80,160,  0
	BYTE	 70, 70, 70, 70, 70, 70
Door:
	BYTE 2,3
	BYTE	  0,127, 64, 95, 88, 80, 80, 80
	BYTE	  0,254,  2,250, 26, 10, 10, 10
	BYTE	 80, 80, 80, 80, 80, 88, 95, 95
	BYTE	 10, 10, 10, 10, 10, 26,250,250
	BYTE	 83, 95, 95, 95, 95, 95, 95, 95
	BYTE	250,250,250,250,250,250,250,250
	BYTE	  6,  6,  6,  6,  6,  6
Car:
	BYTE 4,2
	BYTE	  0,  0,  0,  0,  1,  3,  7, 62
	BYTE	  0,  0,127,194,130,  2,  2,  2
	BYTE	  0,  0,224, 16,  8,  4,  2,  3
	BYTE	  0,  0,  0,  0,  0,  0,  0,192
	BYTE	126,126,226,221,166, 42, 54, 28
	BYTE	253,157,125, 61,128,127,  0,  0
	BYTE	251,203,247,246, 13,253,  1,  0
	BYTE	252,255, 31,239, 55, 86,176,224
	BYTE	67,67,67,67,3,3,3,3
House1:
	BYTE 1,2
	BYTE	255,255,254,254,252,252,248,248
	BYTE	240,240,224,224,192,192,128,128
	BYTE	  1,  1
House2:
	BYTE 1,2
	BYTE	255,255,127,127, 63, 63, 31, 31
	BYTE	 15, 15,  7,  7,  3,  3,  1,  1
	BYTE	  1,  1
House3:
	BYTE 1,2
	BYTE	255,255,254,  0,252,252,248,  0
	BYTE	240,240,224,  0,192,192,128,  0
	BYTE	 10, 10
House4:
	BYTE 1,2
	BYTE	255,255,255,  0, 63, 63, 31,  0
	BYTE	 15, 15,  7,  0,  3,  3,  1,  0
	BYTE	 10, 10
House5
	BYTE 1,1
	BYTE 255,255,255,255,255,255,255,255
	BYTE 1
House6
	BYTE 1,1
	BYTE 255,255,255,0,255,255,255,0
	BYTE 2	
Brick:
	BYTE 1,1
	BYTE	255,128,128,128,255,  8,  8,  8
	BYTE	 23
	
Girl
	.BYTE 2,2
	.BYTE	  0,  0,  0,  0,  0,  0,  1,  1
	.BYTE	  0,  0,  0,  0, 96,144,104,104
	.BYTE	  1,  0,  6, 15, 11, 25, 48,  0
	.BYTE	  4,112,248, 44,148,114,226,  0
	.BYTE	 70, 70, 70,  6
	
	
Bike1:
	.BYTE 3,2
	.BYTE	 16
	.BYTE	112,136,184,112,224,255,189,192
	.BYTE	  0,  0,  0,  0,  0,  0,128,192
	.BYTE	 30, 33, 94, 51, 45, 33, 51, 30
	.BYTE	240,120, 61, 12, 46, 49, 24,  0
	.BYTE	120,132,122,204,132,180,204,120
	.BYTE 71,71,71,71,71,71
Bike2:
	.BYTE 3,2
	.BYTE	 16
	.BYTE	112,136,184,112,224,255,189,192
	.BYTE	  0,  0,  0,  0,  0,  0,128,192
	.BYTE	 30, 33, 94, 51, 33, 45, 51, 30
	.BYTE	240,120, 59, 92,108, 12, 14,  0
	.BYTE	120,132,122,204,180,132,204,120
	.BYTE 71,71,71,71,71,71
	
Bike3:
	.BYTE 3,2
	.BYTE	  0,  0,  0,  0,  0,  0,  1,  3
	.BYTE	 14, 17, 29, 14,  7,255,189,  3
	.BYTE	  16
	.BYTE	 30, 33, 94, 51, 33, 45, 51, 30
	.BYTE	 15, 30,188, 48,116,140, 24,  0
	.BYTE	120,132,122,204,180,132,204,120
	.BYTE	  71, 71,  71,  71,  71,  71

Bike4:
	.BYTE 3,2
	.BYTE	  0,  0,  0,  0,  0,  0,  1,  3
	.BYTE	 14, 17, 29, 14,  7,255,189,  3
	.BYTE	  16
	.BYTE	 30, 33, 94, 51, 45, 33, 51, 30
	.BYTE	 15, 30,220, 58, 54, 48,112,  0
	.BYTE	120,132,122,204,132,180,204,120
	.BYTE	  71,  71,  17,  71,  71,  71
	
PlayerWalk1
	.BYTE 2,2
	.BYTE	  1,  2,  2,  1,  6, 15, 23, 27
	.BYTE	128, 64,192,128, 96,240,232,216
	.BYTE	 27, 48, 51,  6, 12, 12, 28,  0
	.BYTE	216, 24,204,204,224, 96, 96,112
	.BYTE	65,1,65,1
PlayerWalk2
	.BYTE 2,2
	.BYTE	  1,  2,  2,  1,  6, 15, 23, 27
	.BYTE	128, 64,192,128, 96,240,232,216
	.BYTE	 27, 24, 51, 51,  7,  6,  6, 14
	.BYTE	216, 12,204, 96, 48, 48, 56,  0
	.BYTE 65,1,65,1
PlayerStand1
	.BYTE 2,2
	.BYTE	  1,  2,  2,  1,  6, 15, 23, 59
	.BYTE	128, 64,192,128, 96,240,232,216
	.BYTE	 51, 24, 27,  6,  6,  6, 28, 12
	.BYTE	216, 24,204,204,224, 96, 96,112
	.BYTE 65,1,65,1
PlayerStand2
	.BYTE 2,2	
	.BYTE	  1,  2,  3,  1,  6, 15, 23, 59
	.BYTE	128, 64, 64,128, 96,240,232,216
	.BYTE	 51, 24, 27,  6,  6, 14, 12, 28
	.BYTE	216, 24,204,204,224, 96, 96,112
	.BYTE 65,1,65,1
	
Couple1
	.BYTE 3,2
	.BYTE	16
	.BYTE	255,255,255,255,255,255,255,224
	.BYTE	255,255,255,255,255,255, 31, 15
	.BYTE	255,254,248,240,195,140,144,163
	.BYTE	  0,  1,  1,  8,252, 48,  0,  0
	.BYTE	 15, 63,255,159, 15, 15,  7, 71
	.BYTE	 80, 66, 66, 66, 66, 66	
	
Couple2
	.BYTE 3,2
	.BYTE	16
	.BYTE	255,255,255,255,255,255,252,248
	.BYTE	255,255,255,255,255,255,127, 63
	.BYTE	255,255,255,254,250,228,197,217
	.BYTE	192,128,131, 70, 42, 16,  0,128
	.BYTE	 63,255, 63, 31, 15, 15, 79,255
	.BYTE	 80, 66, 66, 66, 66, 66	
	
Smoke1
	.BYTE 2,2
	.BYTE	 48, 32, 32, 32, 16, 16,  0, 22
	.BYTE	  0,  0,  0,  0,  0, 96,208,208
	.BYTE	  0,  6,  5,  3,  1,  0,  1,  2
	.BYTE	 96, 18, 58,154,214,214, 36,236
	.BYTE	  7, 68,  4,  4
	
Smoke2
	.BYTE 2,2
	.BYTE	 32, 32, 16, 16, 16, 32,  0, 44
	.BYTE	  0,  0,  0,  0,  0, 96,208,208
	.BYTE	  0, 12, 11,  3,  1,  0,  1,  2
	.BYTE	 96, 18, 58,218,214, 54,228,236
	.BYTE	  7, 68,  4,  4
	
Water:
	.BYTE 1,5
	.BYTE	  0,127, 85,  0,247,247, 85,  0
	.BYTE	255,255, 85,170, 85,  0, 85,  0
	.BYTE	 85,  0,  0, 85,  0,  0,  0,  0
	.BYTE	 96,  0,  6,  0,  0, 24,  0,129
	.BYTE	  0,  0, 12,  0, 112,  0,  3,  0
	.BYTE	  7, 79, 79, 79, 79


Roof:
	.BYTE	4,3
	.BYTE	16
	.BYTE	16
	.BYTE	255,255,255,255,231,195,129,  0
	.BYTE	16
	.BYTE	16
	.BYTE	254,252,248,240,224,192,128,  0
	.BYTE	255,255,255,255,231,195,129,  0
	.BYTE	127, 63, 31, 15,  7,  3,  1,  0
	.BYTE	126, 62, 60, 28, 28,  8,  8,  0
	.BYTE	254,252,248,240,224,192,128,  0
	.BYTE	255,153,153,153,255,153,153,255
	.BYTE	127, 63, 31, 15,  7,  3,  1,  0
	.BYTE	  40,  40, 29,  40,  40, 29, 11, 29,29, 11,  7, 11
	
Windows:
	.BYTE 1,5
	.BYTE	  0,  0,  0,  0,  0,  0,255,255
	.BYTE	153,153,153,153,255,153,153,153
	.BYTE	255,255,  0,  0,  0,  0,255,255
	.BYTE	153,153,153,153,255,153,153,153
	.BYTE	255,255,  0,  0,  0,  0,  0,  0
	.BYTE	 15,  7, 15,  7, 15

Connection1
	.BYTE 1,1
	.BYTE 7,7,7,7,7,7,7,7
	.BYTE 10 
	
Connection2
	.BYTE 1,1
	.BYTE 15,15,15,15,15,15,15,15
	.BYTE 17 
	
;----------------------
;SCREEN POSITIONS OF GRAPHIC ELEMENTS
BlocksData:
	BYTE 11,6
	WORD Brick
	BYTE 64,0

	BYTE 11,6
	WORD Brick
	BYTE 64,21
	
	BYTE 4,3
	WORD Blank
	BYTE 64,69
	
	BYTE 4,3
	WORD Blank
	BYTE 64,89
		
	BYTE 2,4
	WORD House5
	BYTE 64,11
	
	BYTE 2,4
	WORD House5
	BYTE 64,19
	
	BYTE 7,4
	WORD House6
	BYTE 80,64
	
	BYTE 7,4
	WORD House6
	BYTE 80,64+25

	BYTE 1,2
	WORD House5
	BYTE 80,135
	
	BYTE 1,2
	WORD House5
	BYTE 80,152
	
TilesData:
	
	WORD House1
	BYTE 64,139

	WORD House1
	BYTE 64,76
	
	WORD House1
	BYTE 64,13
	
	WORD House2
	BYTE 64,18
	
	WORD House2
	BYTE 64,83

	WORD House2
	BYTE 64,148	
	
	WORD CoffeeShop
	BYTE 64,0
	
	WORD Door
	BYTE 64,97
	
	WORD Door
	BYTE 64,118
	
	WORD Car
	BYTE 64,203
	
	WORD Car
	BYTE 64,208
	
	WORD SexShop
	BYTE 64,22
	
	WORD Girl
	BYTE 64,122
	
	WORD House3
	BYTE 80,71
	
	WORD House4
	BYTE 80,88
	
	WORD House3
	BYTE 80,134
	
	WORD House4
	BYTE 80,153
	
	WORD Car
	BYTE 80,6
	
	WORD Car
	BYTE 80,11
	
	WORD Car
	BYTE 80,16
	
	WORD Car
	BYTE 80,21
	
	WORD Bank
	BYTE 80,104
	
	WORD Hotel
	BYTE 80,117